# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [TBD] - TBD

### Added

### Changed

### Deprecated

### Removed

### Fixed

### Security

## [0.1.3] - 2024-08-01

### Added

- Added support for Mistral, Fireworks and Azure OpenAI.

### Changed

### Deprecated

### Removed

### Fixed

### Security


## [0.1.2] - 2024-08-01

### Added

- Anthropic Integration [#6](https://github.com/syn54x/just-whisper/pull/6)

### Changed

### Deprecated

### Removed

### Fixed

### Security

## [0.1.1] - 2024-08-01

### Added

- Add github-pages documentation using mkdocs [#2](https://github.com/syn54x/just-whisper/pull/2)


### Changed

- Update `pyproject.toml` to specify Python version >= 3.10.
- Update `pyproject.toml` to specify `uv` as the build system [#3](https://github.com/syn54x/just-whisper/pull/3).

### Deprecated

### Removed

### Fixed

- Fix str has no snippet [#3](https://github.com/syn54x/just-whisper/issues/3)

### Security

## [0.1.0] - 2024-07-30

### Added

- Initial setup of the project structure.
- Basic command-line interface for the Whisper application.
- Project initialization with basic configuration and dependencies as specified in `pyproject.toml`.
- Implementation of Whisper CLI commands in `src/whisper/__init__.py` (startLine: 27, endLine: 92).
- Configuration management commands in `src/whisper/config.py` (startLine: 1, endLine: 36).

### Changed

### Deprecated

### Removed

### Fixed

### Security
